
# THIS FILE IS GENERATED FROM SCIPY SETUP.PY
short_version = '0.1.28'
version = '0.1.28'
full_version = '0.1.28.dev1550245766'
dev_version = '1550245766'
release = False
if not release:
    version = full_version
